package com.nullchat.service;

import java.io.UnsupportedEncodingException;
import java.util.logging.Level;
import java.util.logging.Logger;
import com.nullchat.service.Header;

public class ChatMessage {
	private String text;
	private byte[] rawText;
	private Header h;
	public static final String ENCODING = "utf-8";
	public static final int MAX_POST_LENGTH = 255;
	
	public ChatMessage(String text)  {
		makeMessage(text);
	}

	public ChatMessage(byte[] rawText){
		makeMessage(rawText);
	}

	public void setHeader(Header h) {
		this.h = h;
		h.computeLength(rawText.length);
	}

	public Header getHeader() {
		return h;
	}
	
	private void makeMessage(String text) {
		if (text.length() > MAX_POST_LENGTH)
			text = text.substring(0, MAX_POST_LENGTH-1);
		this.text = text;
		try {
			rawText = text.getBytes(ENCODING);
		} catch (UnsupportedEncodingException e) {
			rawText = text.getBytes();
			Logger.getLogger(ChatMessage.class.getName()).log(Level.WARNING, "getBytes() in encoding "+ ENCODING + " failed, using default encoding");
		}
	}

	private void makeMessage(byte[] rawText)
		 {
		try {
			text = new String(rawText, ENCODING);
		} catch (UnsupportedEncodingException e) {
			text = new String(rawText);
			Logger.getLogger(ChatMessage.class.getName()).log(Level.WARNING, "new String() in encoding "+ ENCODING + " failed, using default encoding");
		}
		this.rawText = rawText;
	}

	public void removeHeader() {
		h = null;
	}

	public String toString() {
		return text;
	}
	
	public byte[] getBytes(){
	return rawText;	
	}
}
